@@ -58,15 +58,22 @@ GSTPPipelineDescription audiosink_pipelines[] = {
 #endif
 	{PIPE_TYPE_AUDIOSINK, 0,"OSS - Open Sound System", 
 	 "osssink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, TRUE},
+	{PIPE_TYPE_AUDIOSINK, 0,"Polypaudio Sound Server", 
+	 "polypsink", FALSE, TEST_PIPE_SUPPLIED, audiosink_test_pipe, FALSE},
 	{PIPE_TYPE_AUDIOSINK, 0, N_("Custom"), NULL, TRUE, TEST_PIPE_SUPPLIED,
 	 audiosink_test_pipe, TRUE}
 };
 
 GSTPPipelineDescription videosink_pipelines[] = {
+#if 0
+  /*
+   * aasink is disabled because it is not a serious alternative.
+   */
 	{PIPE_TYPE_VIDEOSINK, 0,"Ascii Art - X11", "aasink driver=0", FALSE,
 	 TEST_PIPE_SUPPLIED, videosink_test_pipe, FALSE},
 	{PIPE_TYPE_VIDEOSINK, 0,"Ascii Art - console", "aasink driver=1", FALSE,
 	 TEST_PIPE_SUPPLIED, videosink_test_pipe, FALSE},
+#endif
 #if 0 
  /* Leaving this one disabled, because of a bug in cacasink that
   * pops up a window in NULL state
@@ -95,6 +102,8 @@ GSTPPipelineDescription audiosrc_pipelines[] = {
 #endif
 	{PIPE_TYPE_AUDIOSRC, 0,"OSS - Open Sound System", "osssrc", FALSE,
 	 TEST_PIPE_AUDIOSINK, NULL, FALSE},
+	{PIPE_TYPE_AUDIOSRC, 0,"Polypaudio Sound Server", "polypsrc", FALSE,
+	 TEST_PIPE_AUDIOSINK, NULL, FALSE},
 	{PIPE_TYPE_AUDIOSRC, 0,"Silence", "silence", FALSE, TEST_PIPE_AUDIOSINK,
 	 NULL, FALSE},
 	{PIPE_TYPE_AUDIOSRC, 0, N_("Custom"), NULL, TRUE, TEST_PIPE_AUDIOSINK, NULL,
